package moveImages;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

import javax.imageio.ImageIO;
import javax.imageio.ImageReader;
import javax.imageio.stream.ImageInputStream;

public class MoveImages {

	public static void main(String []args){
		try{
			if(args.length != 2 || (!args[1].equals("L") && !args[1].equals("P"))){
				print("Wrong parameters!\nMoveImages <folder that contains images> <L or P>");
				return;
			}
			String imageOrientation = args[1];
			ImageReader reader = ImageIO.getImageReadersByFormatName("jpg").next();
			File imagesFolder;
			File newFolder;
			imagesFolder = new File(args[0]);
			if(!imagesFolder.canWrite() || !imagesFolder.isDirectory()){
				print("could not find folder: " + imagesFolder);
				return;
			}
			newFolder = new File(imagesFolder.getCanonicalPath() + File.separatorChar + "moveImages" + File.separatorChar);
			if(!newFolder.mkdir() && !newFolder.exists()){
				print("could not create folder: " + newFolder);
				return;
			}

			File[] imageFolderList = imagesFolder.listFiles();

			for(File current:imageFolderList){
				ImageInputStream iis;
				float aspectRatio;

				try{
					iis = ImageIO.createImageInputStream(current);

					reader.setInput(iis, true);
					aspectRatio = reader.getAspectRatio(0);

				}catch(java.lang.IllegalStateException e){continue;
				}catch(javax.imageio.IIOException e){continue;
				}

				if(imageOrientation.equals("P")){
					if(aspectRatio < 1.0){
						File newFile = new File(newFolder.getCanonicalPath() + File.separatorChar + current.getName());
						copyFile(newFile,current);
					}
				}else{
					if(aspectRatio > 1.0){
						File newFile = new File(newFolder.getCanonicalPath() + File.separatorChar + current.getName());
						copyFile(newFile,current);
					}
				}
			}
		}catch(IOException e){e.printStackTrace();}
	}


	static void print(Object o){
		System.out.println(o);
	}

	static void copyFile(File to,File from) throws IOException{
		BufferedInputStream fromStream = new BufferedInputStream(new FileInputStream(from));
		BufferedOutputStream toStream = new BufferedOutputStream(new FileOutputStream(to));
		int bytesRead;
		byte[] buffer = new byte[1024];
		while ((bytesRead = fromStream.read(buffer)) != -1)
			toStream.write(buffer, 0, bytesRead); // write
	}
}
